@@ -4,7 +4,7 @@
 ///
 
 /*
-    Copyright (C) 2005-2011, Net Direct Inc. (http://www.netdirect.ca/)
+    Copyright (C) 2005-2012, Net Direct Inc. (http://www.netdirect.ca/)
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -38,6 +38,12 @@ namespace Barry {
 class BXEXPORT Message : public MessageBase
 {
 public:
+	Message()
+	{
+		// must call this again, since base class can't call ours
+		Clear();
+	}
+
 	void Clear()
 	{
 		MessageBase::Clear();
@@ -49,6 +55,9 @@ public:
 	// database name
 	static const char * GetDBName() { return "Messages"; }
 	static uint8_t GetDefaultRecType() { return 0; }
+
+	// Generic Field Handle support
+	static const FieldHandle<Message>::ListT& GetFieldHandles();
 };
 
 BXEXPORT inline std::ostream& operator<<(std::ostream &os, const Message &msg) {
