@@ -4,7 +4,7 @@
 ///
 
 /*
-    Copyright (C) 2008-2011, Net Direct Inc. (http://www.netdirect.ca/)
+    Copyright (C) 2008-2012, Net Direct Inc. (http://www.netdirect.ca/)
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -25,7 +25,6 @@
 
 #include <barry/barry.h>
 #include <sstream>
-#include <getopt.h>
 #include <vector>
 #include <list>
 #include <string>
@@ -36,8 +35,11 @@
 #include <sys/types.h>
 #include <fcntl.h>
 #include <string.h>
+#include <stdlib.h>
 #include "i18n.h"
 
+#include "barrygetopt.h"
+
 using namespace std;
 using namespace std::tr1;
 using namespace Barry;
@@ -62,12 +64,12 @@ string cmdline_password;
 
 void Blurb()
 {
-   int major, minor;
-   const char *Version = Barry::Version(major, minor);
+   int logical, major, minor;
+   const char *Version = Barry::Version(logical, major, minor);
 
    cerr
    << "bfuse - FUSE filesystem for Blackberry databases\n"
-   << "        Copyright 2008-2011, Net Direct Inc. (http://www.netdirect.ca/)\n"
+   << "        Copyright 2008-2012, Net Direct Inc. (http://www.netdirect.ca/)\n"
    << "        Using: " << Version << "\n"
    << endl;
 }
@@ -206,10 +208,10 @@ ParserPtr GetParser(const string &name, std::ostream &os, bool null_parser)
 			new RecordParser<Folder, Store<Folder> > (
 				new Store<Folder>(os)));
 	}
-	else if( name == Timezone::GetDBName() ) {
+	else if( name == TimeZone::GetDBName() ) {
 		return ParserPtr(
-			new RecordParser<Timezone, Store<Timezone> > (
-				new Store<Timezone>(os)));
+			new RecordParser<TimeZone, Store<TimeZone> > (
+				new Store<TimeZone>(os)));
 	}
 	else {
 		// unknown database, use null parser
